Crate datachannel_sys[−][src]
Structs
| __fsid_t | |
| rtcConfiguration | |
| rtcDataChannelInit | |
| rtcReliability | |
| rtcWsConfiguration |
Constants
Functions
| rtcAddRemoteCandidate⚠ | |
| rtcAddTrack⚠ | |
| rtcAddTrackEx⚠ | Add track @param pc Peer connection id @param codec Codec @param payloadType Payload type @param ssrc SSRC @param _mid MID @param _direction Direction @param _name Name (optional) @param _msid MSID (optional) @param _trackID Track ID used in MSID (optional) @returns Track id |
| rtcChainRtcpNackResponder⚠ | Chain RtcpNackResponder to handler chain for given track @param tr Track id @param maxStoredPacketsCount Maximum stored packet count |
| rtcChainRtcpSrReporter⚠ | Chain RtcpSrReporter to handler chain for given track @param tr Track id |
| rtcCleanup⚠ | |
| rtcCreateDataChannel⚠ | |
| rtcCreateDataChannelEx⚠ | |
| rtcCreatePeerConnection⚠ | |
| rtcCreateWebSocket⚠ | |
| rtcCreateWebSocketEx⚠ | |
| rtcDeleteDataChannel⚠ | |
| rtcDeletePeerConnection⚠ | |
| rtcDeleteTrack⚠ | |
| rtcDeleteWebsocket⚠ | |
| rtcGetAvailableAmount⚠ | |
| rtcGetBufferedAmount⚠ | |
| rtcGetCurrentTrackTimestamp⚠ | Get current timestamp @param id Track id @param timestamp Pointer for result |
| rtcGetDataChannelLabel⚠ | |
| rtcGetDataChannelProtocol⚠ | |
| rtcGetDataChannelReliability⚠ | |
| rtcGetDataChannelStream⚠ | |
| rtcGetLocalAddress⚠ | |
| rtcGetLocalDescription⚠ | |
| rtcGetLocalDescriptionType⚠ | |
| rtcGetPreviousTrackSenderReportTimestamp⚠ | Get timestamp of previous RTCP SR @param id Track id @param timestamp Pointer for result |
| rtcGetRemoteAddress⚠ | |
| rtcGetRemoteDescription⚠ | |
| rtcGetRemoteDescriptionType⚠ | |
| rtcGetSelectedCandidatePair⚠ | |
| rtcGetTrackDescription⚠ | |
| rtcGetTrackStartTimestamp⚠ | Get start timestamp for track identified by given id @param id Track id @param timestamp Pointer for result |
| rtcGetUserPointer⚠ | |
| rtcInitLogger⚠ | |
| rtcPreload⚠ | |
| rtcReceiveMessage⚠ | |
| rtcSendMessage⚠ | |
| rtcSetAvailableCallback⚠ | |
| rtcSetBufferedAmountLowCallback⚠ | |
| rtcSetBufferedAmountLowThreshold⚠ | |
| rtcSetClosedCallback⚠ | |
| rtcSetDataChannelCallback⚠ | |
| rtcSetErrorCallback⚠ | |
| rtcSetGatheringStateChangeCallback⚠ | |
| rtcSetH264PacketizationHandler⚠ | Set H264PacketizationHandler for track @param tr Track id @param ssrc SSRC @param cname CName @param payloadType Payload Type @param clockRate Clock rate @param maxFragmentSize Maximum NALU fragment size @param sequenceNumber Sequence number @param timestamp Timestamp |
| rtcSetLocalCandidateCallback⚠ | |
| rtcSetLocalDescription⚠ | |
| rtcSetLocalDescriptionCallback⚠ | |
| rtcSetMessageCallback⚠ | |
| rtcSetNeedsToSendRtcpSr⚠ | Set |
| rtcSetOpenCallback⚠ | |
| rtcSetOpusPacketizationHandler⚠ | Set OpusPacketizationHandler for track @param tr Track id @param ssrc SSRC @param cname CName @param payloadType Payload Type @param clockRate Clock rate @param _sequenceNumber Sequence number @param _timestamp Timestamp |
| rtcSetRemoteDescription⚠ | |
| rtcSetRtpConfigurationStartTime⚠ | Set start time for RTP stream
@param startTime_s Start time in seconds
@param timeIntervalSince1970 Set true if |
| rtcSetSignalingStateChangeCallback⚠ | |
| rtcSetStateChangeCallback⚠ | |
| rtcSetTrackCallback⚠ | |
| rtcSetTrackRTPTimestamp⚠ | Set RTP timestamp for track identified by given id @param id Track id @param timestamp New timestamp |
| rtcSetUserPointer⚠ | |
| rtcStartRtcpSenderReporterRecording⚠ | Start stats recording for RTCP Sender Reporter @param id Track identifier |
| rtcTransformSecondsToTimestamp⚠ | Transform seconds to timestamp using track’s clock rate @param id Track id @param seconds Seconds @param timestamp Pointer to result |
| rtcTransformTimestampToSeconds⚠ | Transform timestamp to seconds using track’s clock rate @param id Track id @param timestamp Timestamp @param seconds Pointer for result |